class _StandardActionCodes:
    """
    Private class holding standard credit card action codes.
    Meant to be used internally by card-specific classes.
    """
    standard_codes = {
        "00": "Approved or completed successfully",
        "01": "Refer to card issuer",
        "02": "Refer to card issuer's special conditions",
        "03": "Invalid merchant",
        "04": "Pick-up",
        "05": "Do not honor",
        "06": "Error",
        "07": "Pick-up card, special condition",
        "08": "Honour with identification",
        "09": "Request in progress",
        "10": "Approved for partial amount",
        "11": "Approved (VIP)",
        "12": "Invalid transaction",
        "13": "Invalid amount",
        "14": "Invalid card number (no such number)",
        "15": "No such issuer",
        "16": "Approved, update track 3",
        "17": "Customer cancellation",
        "18": "Customer dispute",
        "19": "Re-enter transaction",
        "20": "Invalid response",
        "21": "No action taken",
        "22": "Suspected malfunction",
        "23": "Unacceptable transaction fee",
        "24": "File update not supported by receiver",
        "25": "Unable to locate record on file",
        "26": "Duplicate file update record, old record replaced",
        "27": "File update field edit error",
        "28": "File update file locked out",
        "29": "File update not successful, contact acquirer",
        "30": "Format error",
        "31": "Bank not supported by switch",
        "32": "Completed partially",
        "33": "Expired card",
        "34": "Suspected fraud",
        "35": "Card acceptor contact acquirer",
        "36": "Restricted card",
        "37": "Card acceptor call acquirer security",
        "38": "Allowable PIN tries exceeded",
        "39": "No credit account",
        "40": "Requested function not supported",
        "41": "Lost card",
        "42": "No universal account",
        "43": "Stolen card, pick-up",
        "44": "No investment account",
        "45": "Reserved for ISO use",
        "46": "Reserved for ISO use",
        "47": "Reserved for ISO use",
        "48": "Reserved for ISO use",
        "49": "Reserved for ISO use",
        "50": "Reserved for ISO use",
        "51": "Not sufficient funds",
        "52": "No checking account",
        "53": "No savings account",
        "54": "Expired card",
        "55": "Incorrect personal identification number",
        "56": "No card record",
        "57": "Transaction not permitted to cardholder",
        "58": "Transaction not permitted to terminal",
        "59": "Suspected fraud",
        "60": "Card acceptor contact acquirer",
        "61": "Exceeds withdrawal amount limit",
        "62": "Restricted card",
        "63": "Security violation",
        "64": "Original amount incorrect",
        "65": "Exceeds withdrawal frequency limit",
        "66": "Card acceptor call acquirer's security department",
        "67": "Hard capture (requires that card be picked up at ATM)",
        "68": "Response received too late",
        "69": "Reserved for ISO use",
        "70": "Reserved for ISO use",
        "71": "Reserved for ISO use",
        "72": "Reserved for ISO use",
        "73": "Reserved for ISO use",
        "74": "Reserved for ISO use",
        "75": "Allowable number of PIN tries exceeded",
        "76": "Reserved for private use",
        "77": "Reserved for private use",
        "78": "Card not activated",
        "79": "Reserved for private use",
        "80": "Visa transactions: credit issuer unavailable",
        "81": "Reserved for private use",
        "82": "Invalid card expiration date",
        "83": "Reserved for private use",
        "84": "Reserved for private use",
        "85": "Success: address verification",
        "86": "Reserved for private use",
        "87": "Reserved for private use",
        "88": "Reserved for private use",
        "89": "Reserved for private use",
        "90": "Cutoff is in process (switch ending a day\'s business and starting the next. Transaction can be sent again in a few minutes)",
        "91": "Issuer or switch is inoperative",
        "92": "Financial institution or intermediate network facility cannot be found for routing",
        "93": "Transaction cannot be completed. Violation of law",
        "94": "Duplicate transmission",
        "95": "Reconcile error",
        "96": "System malfunction",
        "97": "Reserved for national use",
        "98": "Reserved for national use",
        "99": "Reserved for national use"
    }

    @classmethod
    def get_standard_description(cls, action_code: str) -> str:
        return cls.standard_codes.get(action_code, "Unknown action code")

    @classmethod
    def get_all_standard_codes(cls) -> dict:
        return cls.standard_codes