from ._standard_action_codes import _StandardActionCodes

class VisaActionCodes(_StandardActionCodes):
    def __init__(self):
        self.visa_specific_codes = {
            "00": "Approved and completed successfully",
            "01": "Refer to card issuer",
            "02": "Refer to card issuer, special condition",
            "03": "Invalid merchant",
            "04": "Pick up card (no fraud)",
            "05": "Do not honor",
            "06": "Error",
            "07": "Pick up card, special condition (fraud account)",
            "10": "Partial approval",
            "11": "Approved (V.I.P)",
            "12": "Invalid transaction",
            "13": "Invalid amount or currency conversion field overflow",
            "14": "Invalid account number (no such number)",
            "15": "No such issuer",
            "19": "Re-enter transaction",
            "21": "No action taken",
            "25": "Unable to locate record in file",
            "28": "File temporarily not available for update or inquiry",
            "39": "No credit account",
            "41": "Lost card, pick up (fraud account)",
            "43": "Stolen card, pick up (fraud account)",
            "46": "Closed account",
            "51": "Not sufficient funds",
            "52": "No checking account",
            "53": "No savings account",
            "54": "Expired card or expiration date is missing",
            "55": "Incorrect PIN or PIN missing",
            "57": "Transaction not permitted to cardholder",
            "58": "Transaction not allowed at terminal",
            "59": "Suspected fraud",
            "61": "Exceeds approval amount limit",
            "62": "Restricted card (card invalid in this region or country)",
            "63": "Security violation (source is not correct issuer)",
            "64": "Transaction does not fulfill AML requirement",
            "65": "Exceeds withdrawal frequency limit",
            "70": "PIN data required",
            "74": "Different value than that used for PIN encryption errors",
            "75": "Allowable number of PIN entry tries exceeded",
            "76": "Unsolicited reversal",
            "78": "“Blocked, first used”—Transaction from new cardholder, and card not properly unblocked",
            "79": "Already reversed (by Switch)",
            "80": "No financial impact",
            "81": "Cryptographic error found in PIN",
            "82": "Negative CAM, dCVV, iCVV, or CVV results",
            "85": "No reason to decline a request for address verification, CVV2 verification, or a credit voucher or merchandise return",
            "86": "Cannot verify PIN; for example, no PVV",
            "89": "Ineligible to receive financial position information (GIV)",
            "91": "Issuer or switch inoperative and STIP not applicable or not available for this transaction; Time-out when no stand-in; POS Check Service: Destination unavailable; Credit Voucher and Merchandise Return Authorizations: V.I.P. sent the transaction to the issuer, but the issuer was unavailable.",
            "92": "Financial institution or intermediate network facility cannot be found for routing (receiving institution ID is invalid)",
            "93": "Transaction cannot be completed - violation of law",
            "96": "System malfunction",
            "1A": "Additional customer authentication required",
            "6P": "Verification data failed",
            "B1": "Surcharge amount not permitted on Visa cards or EBT food stamps (U.S. acquirers only)",
            "B2": "Surcharge amount not supported by debit network issuer.",
            "N0": "Force STIP",
            "N3": "Cash service not available",
            "N4": "Cash request exceeds issuer or approved limit",
            "N5": "Ineligible for resubmission",
            "N7": "Decline for CVV2 failure",
            "N8": "Transaction amount exceeds preauthorized approval amount",
            "P5": "Denied PIN unblock—PIN change or unblock request declined by issuer",
            "P6": "Denied PIN change—requested PIN unsafe",
            "Q1": "Card Authentication failed",
            "R0": "Stop Payment Order",
            "R1": "Revocation of authorization order",
            "R2": "Transaction does not qualify for Visa PIN",
            "R3": "Revocation of all authorizations order",
            "Z3": "Unable to go online; offline-declined",
        }

    def get_action_description(self, action_code: str) -> str:
        return self.visa_specific_codes.get(action_code, super().get_standard_description(action_code))

    def get_all_codes(self) -> dict:
        combined_codes = self.visa_specific_codes.copy()
        combined_codes.update(self.get_all_standard_codes())
        return combined_codes
